@@ -12,7 +12,7 @@ with open(__folder__.joinpath('build_cffi.c-files.txt').as_posix(), 'r') as f:
 # end with
 
 ext_dir = __folder__.joinpath('_image_intensities')
-sources = [ext_dir.joinpath(s).as_posix() for s in sources]
+sources = [ext_dir.joinpath(s).as_posix() for s in sources if s]
 
 ffibuilder = cffi.FFI()
 args = dict(
@@ -29,7 +29,7 @@ args = dict(
         "./_native_code/jpeg",
         "./_native_code/png",
     ],
-    sources=[f'./_native_code/{filename}' for filename in sources if filename],
+    sources=sources,
     extra_compile_args=[
         "-std=c99",
         "-fPIC",
